#!/usr/bin/env sh

# ----------------------------------------------------------- #
# Copyright (C) 2008 Red Hat, Inc.                            #
# Written by Michel Samia <msamia@redhat.com>                 #
# cron.sh                                                     #
# more info in cron.sh                                        #
# ----------------------------------------------------------- #


. "${TESTS_DIRS}/bash_defs.sh"

W_PATH_RELATIVE=1
E_GROUP_WRITABLE=3
E_WORLD_WRITABLE=4
E_NOT_OWNED_BY_ROOT=5

if [[ "`crontab -l | grep -c '^no crontab for'`" == "1" ]]
then
	exit
fi

crontab -l |
{
	while read minutes hours daymonth month dayweek command
	do
		# is the path absolute?
		if [[ "${command:1:1}" != "/" ]]
		then
			report 'WARNING' $W_PATH_RELATIVE "The command '$command' in crontab has a relative path!"
			report 'HINT' $W_PATH_RELATIVE "Please modify your crontab to specify absolute path of this command!"
		fi

		
		fullpath="`which $command`"
		
		# is this file secure? (means not world/group writable + owned by root
		perm="`stat -L -c '%A' $fullpath`"
		if [[ ${perm:5:1} != '-' ]]
		then
			report 'ERROR' $E_GROUP_WRITABLE "Crontab contains command '$command', which is is group writable"
			report 'HINT' $E_GROUP_WRITABLE "Please unset it the group writing bit"
		fi

		
		if [[ ${perm:8:1} != '-' ]]
		then
			report 'ERROR' $E_WORLD_WRITABLE "Crontab contains command '$command', which is is world writable"
			report 'HINT' $E_WORLD_WRITABLE "Please unset it the world writing bit"
		fi
		
		owner="`stat -c '%U' $fullpath`"
		if [[ "$owner" != "root" ]]
		then
			report 'ERROR' $E_NOT_OWNED_BY_ROOT "Crontab contains command '$command', which is not owned by root"
			report 'HINT' $E_NOT_OWNED_BY_ROOT "Please chown this file to root:root"
		fi
	done
}
